@@ -34,9 +34,6 @@ extern "C"
 #define TDS_STATIC_CAST(type, a) ((type)(a))
 #endif
 
-static const char rcsid_cspublic_h[] = "$Id: cspublic.h,v 1.61 2008-09-08 17:50:25 jklowden Exp $";
-static const void *const no_unused_cspublic_h_warn[] = { rcsid_cspublic_h, no_unused_cspublic_h_warn };
-
 #define CS_PUBLIC
 #define CS_STATIC static
 
@@ -277,7 +274,7 @@ enum
 	CS_TDS_71,
 	CS_TDS_72,
 	CS_TDS_73,
-	CS_TDS_80 = CS_TDS_71,
+	CS_TDS_74,
 };
 
 /* bit mask values used by CS_DATAFMT.status */
@@ -581,6 +578,8 @@ enum
 #define CS_UINT_TYPE        TDS_STATIC_CAST(CS_INT, 32)
 #define CS_UBIGINT_TYPE     TDS_STATIC_CAST(CS_INT, 33)
 #define CS_XML_TYPE         TDS_STATIC_CAST(CS_INT, 34)
+#define CS_BIGDATETIME_TYPE TDS_STATIC_CAST(CS_INT, 35)
+#define CS_BIGTIME_TYPE     TDS_STATIC_CAST(CS_INT, 36)
 #define CS_UNIQUE_TYPE      TDS_STATIC_CAST(CS_INT, 40)
 
 #define CS_USER_TYPE        TDS_STATIC_CAST(CS_INT, 100)
